@@ -31,13 +31,14 @@ qx.Class.define("callbackery.ui.plugin.Html", {
         _html: null,
 	_populate: function(){
             this.setLayout(new qx.ui.layout.VBox(30));
-	    this.add(this._createHtml());
+	    this.add(this._createHtml(),{flex: 1});
 	},
 	_createHtml: function(){
             var html = this._html = new qx.ui.embed.Html().set({
 		overflowX: "auto",
 		overflowY: "auto",
 		nativeContextMenu: true
+		
             });
 	    return html;
 	},
